@@ -150,36 +150,45 @@ typedef enum {
  * @E_CONTENT_EDITOR_INSERT_REPLACE_ALL:
  * @E_CONTENT_EDITOR_INSERT_TEXT_HTML:
  * @E_CONTENT_EDITOR_INSERT_TEXT_PLAIN:
+ * @E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE: Set when should convert plain text into &lt;pre&gt; instead of &lt;div&gt;. Since 3.40
  *
  * Since: 3.22
  **/
 typedef enum {
-	E_CONTENT_EDITOR_INSERT_NONE		= 0,
-	E_CONTENT_EDITOR_INSERT_CONVERT		= 1 << 0,
-	E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT	= 1 << 1,
-	E_CONTENT_EDITOR_INSERT_REPLACE_ALL	= 1 << 2,
-	E_CONTENT_EDITOR_INSERT_TEXT_HTML	= 1 << 3,
-	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN	= 1 << 4,
+	E_CONTENT_EDITOR_INSERT_NONE			= 0,
+	E_CONTENT_EDITOR_INSERT_CONVERT			= 1 << 0,
+	E_CONTENT_EDITOR_INSERT_QUOTE_CONTENT		= 1 << 1,
+	E_CONTENT_EDITOR_INSERT_REPLACE_ALL		= 1 << 2,
+	E_CONTENT_EDITOR_INSERT_TEXT_HTML		= 1 << 3,
+	E_CONTENT_EDITOR_INSERT_TEXT_PLAIN		= 1 << 4,
+	E_CONTENT_EDITOR_INSERT_CONVERT_PREFER_PRE	= 1 << 5
 } EContentEditorInsertContentFlags;
 
 /**
  * EContentEditorGetContentFlags:
- * @E_CONTENT_EDITOR_GET_BODY:
- * @E_CONTENT_EDITOR_GET_INLINE_IMAGES:
- * @E_CONTENT_EDITOR_GET_PROCESSED: raw or processed
- * @E_CONTENT_EDITOR_GET_TEXT_HTML:
- * @E_CONTENT_EDITOR_GET_TEXT_PLAIN:
- * @E_CONTENT_EDITOR_GET_EXCLUDE_SIGNATURE:
+ * @E_CONTENT_EDITOR_GET_INLINE_IMAGES: Return also list of inline images
+ * @E_CONTENT_EDITOR_GET_RAW_BODY_HTML: text/html version of the body only, as used by the editor
+ * @E_CONTENT_EDITOR_GET_RAW_BODY_PLAIN: text/plain version of the body only, as used by the editor
+ * @E_CONTENT_EDITOR_GET_RAW_BODY_STRIPPED: text/plain version of the body only, without signature, quoted text and such
+ * @E_CONTENT_EDITOR_GET_RAW_DRAFT: a version of the content, to use as draft message
+ * @E_CONTENT_EDITOR_GET_TO_SEND_HTML: text/html version of the content, suitable to be sent
+ * @E_CONTENT_EDITOR_GET_TO_SEND_PLAIN:	text/plain version of the content, suitable to be sent
+ * @E_CONTENT_EDITOR_GET_ALL: a shortcut for all flags
  *
- * Since: 3.22
+ * Influences what content should be returned. Each flag means one
+ * version, or part, of the content.
+ *
+ * Since: 3.38
  **/
 typedef enum {
-	E_CONTENT_EDITOR_GET_BODY		= 1 << 0,
-	E_CONTENT_EDITOR_GET_INLINE_IMAGES	= 1 << 1,
-	E_CONTENT_EDITOR_GET_PROCESSED		= 1 << 2, /* raw or processed */
-	E_CONTENT_EDITOR_GET_TEXT_HTML		= 1 << 3,
-	E_CONTENT_EDITOR_GET_TEXT_PLAIN		= 1 << 4,
-	E_CONTENT_EDITOR_GET_EXCLUDE_SIGNATURE	= 1 << 5
+	E_CONTENT_EDITOR_GET_INLINE_IMAGES	= 1 << 0,
+	E_CONTENT_EDITOR_GET_RAW_BODY_HTML	= 1 << 1,
+	E_CONTENT_EDITOR_GET_RAW_BODY_PLAIN	= 1 << 2,
+	E_CONTENT_EDITOR_GET_RAW_BODY_STRIPPED	= 1 << 3,
+	E_CONTENT_EDITOR_GET_RAW_DRAFT		= 1 << 4,
+	E_CONTENT_EDITOR_GET_TO_SEND_HTML	= 1 << 5,
+	E_CONTENT_EDITOR_GET_TO_SEND_PLAIN	= 1 << 6,
+	E_CONTENT_EDITOR_GET_ALL		= ~0
 } EContentEditorGetContentFlags;
 
 /**
@@ -206,30 +215,6 @@ typedef enum {
 	E_CONTENT_EDITOR_NODE_IS_TEXT_COLLAPSED	= 1 << 6
 } EContentEditorNodeFlags;
 
-/**
- * EContentEditorStyleFlags:
- * @E_CONTENT_EDITOR_STYLE_NONE: None from the below.
- * @E_CONTENT_EDITOR_STYLE_IS_BOLD:
- * @E_CONTENT_EDITOR_STYLE_IS_ITALIC:
- * @E_CONTENT_EDITOR_STYLE_IS_UNDERLINE:
- * @E_CONTENT_EDITOR_STYLE_IS_STRIKETHROUGH:
- * @E_CONTENT_EDITOR_STYLE_IS_MONOSPACE:
- * @E_CONTENT_EDITOR_STYLE_IS_SUBSCRIPT:
- * @E_CONTENT_EDITOR_STYLE_IS_SUPERSCRIPT:
- *
- * Since: 3.22
- **/
-typedef enum {
-	E_CONTENT_EDITOR_STYLE_NONE		= 0,
-	E_CONTENT_EDITOR_STYLE_IS_BOLD		= 1 << 0,
-	E_CONTENT_EDITOR_STYLE_IS_ITALIC	= 1 << 1,
-	E_CONTENT_EDITOR_STYLE_IS_UNDERLINE	= 1 << 2,
-	E_CONTENT_EDITOR_STYLE_IS_STRIKETHROUGH	= 1 << 3,
-	E_CONTENT_EDITOR_STYLE_IS_MONOSPACE	= 1 << 4,
-	E_CONTENT_EDITOR_STYLE_IS_SUBSCRIPT	= 1 << 5,
-	E_CONTENT_EDITOR_STYLE_IS_SUPERSCRIPT	= 1 << 6
-} EContentEditorStyleFlags;
-
 /**
  * EContentEditorBlockFormat:
  * @E_CONTENT_EDITOR_BLOCK_FORMAT_NONE:
@@ -292,16 +277,20 @@ typedef enum {
 
 /**
  * EContentEditorAlignment:
+ * @E_CONTENT_EDITOR_ALIGNMENT_NONE:
  * @E_CONTENT_EDITOR_ALIGNMENT_LEFT:
  * @E_CONTENT_EDITOR_ALIGNMENT_CENTER:
  * @E_CONTENT_EDITOR_ALIGNMENT_RIGHT:
+ * @E_CONTENT_EDITOR_ALIGNMENT_JUSTIFY:
  *
  * Since: 3.22
  **/
 typedef enum {
+	E_CONTENT_EDITOR_ALIGNMENT_NONE = -1,
 	E_CONTENT_EDITOR_ALIGNMENT_LEFT = 0,
 	E_CONTENT_EDITOR_ALIGNMENT_CENTER,
-	E_CONTENT_EDITOR_ALIGNMENT_RIGHT
+	E_CONTENT_EDITOR_ALIGNMENT_RIGHT,
+	E_CONTENT_EDITOR_ALIGNMENT_JUSTIFY
 } EContentEditorAlignment;
 
 /**
@@ -534,6 +523,101 @@ typedef enum {
 	E_CONTENT_EDITOR_FIND_WRAP_AROUND	= 1 << 4
 } EContentEditorFindFlags;
 
+/**
+ * EUndoRedoState:
+ * @E_UNDO_REDO_STATE_NONE: Cannot undo, neither redo.
+ * @E_UNDO_REDO_STATE_CAN_UNDO: Undo is available.
+ * @E_UNDO_REDO_STATE_CAN_REDO: Redo is available.
+ *
+ * Flags in what state Undo/Redo stack is.
+ *
+ * Since: 3.38
+ **/
+typedef enum {
+	E_UNDO_REDO_STATE_NONE		= 0,
+	E_UNDO_REDO_STATE_CAN_UNDO	= 1 << 0,
+	E_UNDO_REDO_STATE_CAN_REDO	= 1 << 1
+} EUndoRedoState;
+
+/**
+ * EDnDTargetType:
+ * @DND_TARGET_TYPE_TEXT_URI_LIST: text/uri-list
+ * @DND_TARGET_TYPE_MOZILLA_URL: _NETSCAPE_URL
+ * @DND_TARGET_TYPE_TEXT_HTML: text/html
+ * @DND_TARGET_TYPE_UTF8_STRING: UTF8_STRING
+ * @DND_TARGET_TYPE_TEXT_PLAIN: text/plain
+ * @DND_TARGET_TYPE_STRING: STRING
+ * @DND_TARGET_TYPE_TEXT_PLAIN_UTF8: text/plain;charser=utf-8
+ *
+ * Drag and drop targets supported by EContentEditor.
+ *
+ * Since: 3.26
+ **/
+typedef enum {
+	E_DND_TARGET_TYPE_TEXT_URI_LIST = 0,
+	E_DND_TARGET_TYPE_MOZILLA_URL,
+	E_DND_TARGET_TYPE_TEXT_HTML,
+	E_DND_TARGET_TYPE_UTF8_STRING,
+	E_DND_TARGET_TYPE_TEXT_PLAIN,
+	E_DND_TARGET_TYPE_STRING,
+	E_DND_TARGET_TYPE_TEXT_PLAIN_UTF8
+} EDnDTargetType;
+
+/**
+ * EConfigLookupSourceKind:
+ * @E_CONFIG_LOOKUP_SOURCE_UNKNOWN: unknown source kind
+ * @E_CONFIG_LOOKUP_SOURCE_COLLECTION: collection source
+ * @E_CONFIG_LOOKUP_SOURCE_MAIL_ACCOUNT: mail account source
+ * @E_CONFIG_LOOKUP_SOURCE_MAIL_IDENTITY: mail identity source
+ * @E_CONFIG_LOOKUP_SOURCE_MAIL_TRANSPORT: mail transport source
+ *
+ * Defines what source kind to get in call of e_config_lookup_get_source().
+ *
+ * Since: 3.26
+ **/
+typedef enum {
+	E_CONFIG_LOOKUP_SOURCE_UNKNOWN,
+	E_CONFIG_LOOKUP_SOURCE_COLLECTION,
+	E_CONFIG_LOOKUP_SOURCE_MAIL_ACCOUNT,
+	E_CONFIG_LOOKUP_SOURCE_MAIL_IDENTITY,
+	E_CONFIG_LOOKUP_SOURCE_MAIL_TRANSPORT
+} EConfigLookupSourceKind;
+
+/**
+ * EConfigLookupResultKind:
+ * @E_CONFIG_LOOKUP_RESULT_UNKNOWN: unknown kind
+ * @E_CONFIG_LOOKUP_RESULT_COLLECTION: collection kind, which can serve one or more of the other kinds
+ * @E_CONFIG_LOOKUP_RESULT_MAIL_RECEIVE: configures mail receive
+ * @E_CONFIG_LOOKUP_RESULT_MAIL_SEND: configures mail send
+ * @E_CONFIG_LOOKUP_RESULT_ADDRESS_BOOK: configures address book
+ * @E_CONFIG_LOOKUP_RESULT_CALENDAR: configures calendar
+ * @E_CONFIG_LOOKUP_RESULT_MEMO_LIST: configures memo list
+ * @E_CONFIG_LOOKUP_RESULT_TASK_LIST: configures task list
+ *
+ * Defines config lookup result kind, which is used to distinguish
+ * which part the result configures.
+ *
+ * Since: 3.26
+ **/
+typedef enum {
+	E_CONFIG_LOOKUP_RESULT_UNKNOWN,
+	E_CONFIG_LOOKUP_RESULT_COLLECTION,
+	E_CONFIG_LOOKUP_RESULT_MAIL_RECEIVE,
+	E_CONFIG_LOOKUP_RESULT_MAIL_SEND,
+	E_CONFIG_LOOKUP_RESULT_ADDRESS_BOOK,
+	E_CONFIG_LOOKUP_RESULT_CALENDAR,
+	E_CONFIG_LOOKUP_RESULT_MEMO_LIST,
+	E_CONFIG_LOOKUP_RESULT_TASK_LIST
+} EConfigLookupResultKind;
+
+/**
+ * @E_CONFIG_LOOKUP_RESULT_LAST_KIND:
+ * The last known %EConfigLookupResultKind.
+ *
+ * Since: 3.28
+ **/
+#define E_CONFIG_LOOKUP_RESULT_LAST_KIND E_CONFIG_LOOKUP_RESULT_TASK_LIST
+
 G_END_DECLS
 
 #endif /* E_UTIL_ENUMS_H */
